#ifndef __FUNCTION_H__
#define __FUNCTION_H__

#include <fuse/fuse.h>
#include "buffer.h"

extern	BUFFERMANAGER		OpenFiles;
extern	struct fuse_operations	smb_oper;

int SetFsFreeSpaceBlocks(int size);
int SetFsBlockSize(int size);
int SetFsQuietFlag(int flag);
int SetShowDollarShares(int flag);
int SetKDEworkaround(int count);
int SetUnsafeTruncate(int flag);
int SetFastShutdown(int flag);
int GetFastShutdown(void);
int SetUpdateTimeDelta(int delta);
int GetUpdateTimeDelta(void);

#endif /* __FUNCTION_H__ */
